@@ -39,32 +39,18 @@ module Bootsnap
       cache_dir:,
       development_mode: true,
       load_path_cache: true,
-      autoload_paths_cache: nil,
-      disable_trace: nil,
+      ignore_directories: nil,
+      readonly: false,
       compile_cache_iseq: true,
       compile_cache_yaml: true,
       compile_cache_json: true
     )
-      unless autoload_paths_cache.nil?
-        warn "[DEPRECATED] Bootsnap's `autoload_paths_cache:` option is deprecated and will be removed. " \
-             "If you use Zeitwerk this option is useless, and if you are still using the classic autoloader " \
-             "upgrading is recommended."
-      end
-
-      unless disable_trace.nil?
-        warn "[DEPRECATED] Bootsnap's `disable_trace:` option is deprecated and will be removed. " \
-             "If you use Ruby 2.5 or newer this option is useless, if not upgrading is recommended."
-      end
-
-      if compile_cache_iseq && !iseq_cache_supported?
-        warn "Ruby 2.5 has a bug that break code tracing when code is loaded from cache. It is recommened " \
-             "to turn `compile_cache_iseq` off on Ruby 2.5"
-      end
-
       if load_path_cache
         Bootsnap::LoadPathCache.setup(
           cache_path: "#{cache_dir}/bootsnap/load-path-cache",
           development_mode: development_mode,
+          ignore_directories: ignore_directories,
+          readonly: readonly,
         )
       end
 
@@ -73,20 +59,14 @@ module Bootsnap
         iseq: compile_cache_iseq,
         yaml: compile_cache_yaml,
         json: compile_cache_json,
+        readonly: readonly,
       )
     end
 
-    def self.unload_cache!
+    def unload_cache!
       LoadPathCache.unload!
     end
 
-    def iseq_cache_supported?
-      return @iseq_cache_supported if defined? @iseq_cache_supported
-
-      ruby_version = Gem::Version.new(RUBY_VERSION)
-      @iseq_cache_supported = ruby_version < Gem::Version.new("2.5.0") || ruby_version >= Gem::Version.new("2.6.0")
-    end
-
     def default_setup
       env = ENV["RAILS_ENV"] || ENV["RACK_ENV"] || ENV["ENV"]
       development_mode = ["", nil, "development"].include?(env)
@@ -113,13 +93,19 @@ module Bootsnap
           cache_dir = File.join(app_root, "tmp", "cache")
         end
 
+        ignore_directories = if ENV.key?("BOOTSNAP_IGNORE_DIRECTORIES")
+          ENV["BOOTSNAP_IGNORE_DIRECTORIES"].split(",")
+        end
+
         setup(
           cache_dir: cache_dir,
           development_mode: development_mode,
           load_path_cache: !ENV["DISABLE_BOOTSNAP_LOAD_PATH_CACHE"],
-          compile_cache_iseq: !ENV["DISABLE_BOOTSNAP_COMPILE_CACHE"] && iseq_cache_supported?,
+          compile_cache_iseq: !ENV["DISABLE_BOOTSNAP_COMPILE_CACHE"],
           compile_cache_yaml: !ENV["DISABLE_BOOTSNAP_COMPILE_CACHE"],
           compile_cache_json: !ENV["DISABLE_BOOTSNAP_COMPILE_CACHE"],
+          readonly: !!ENV["BOOTSNAP_READONLY"],
+          ignore_directories: ignore_directories,
         )
 
         if ENV["BOOTSNAP_LOG"]
