@@ -19,9 +19,11 @@ module Bootsnap
         cache_dir: @tmp_dir,
         development_mode: true,
         load_path_cache: true,
-        compile_cache_iseq: Bootsnap.iseq_cache_supported?,
+        compile_cache_iseq: true,
         compile_cache_yaml: true,
         compile_cache_json: true,
+        ignore_directories: nil,
+        readonly: false,
       )
 
       Bootsnap.default_setup
@@ -34,9 +36,11 @@ module Bootsnap
         cache_dir: @tmp_dir,
         development_mode: false,
         load_path_cache: true,
-        compile_cache_iseq: Bootsnap.iseq_cache_supported?,
+        compile_cache_iseq: true,
         compile_cache_yaml: true,
         compile_cache_json: true,
+        ignore_directories: nil,
+        readonly: false,
       )
 
       Bootsnap.default_setup
@@ -49,9 +53,11 @@ module Bootsnap
         cache_dir: @tmp_dir,
         development_mode: true,
         load_path_cache: false,
-        compile_cache_iseq: Bootsnap.iseq_cache_supported?,
+        compile_cache_iseq: true,
         compile_cache_yaml: true,
         compile_cache_json: true,
+        ignore_directories: nil,
+        readonly: false,
       )
 
       Bootsnap.default_setup
@@ -67,6 +73,8 @@ module Bootsnap
         compile_cache_iseq: false,
         compile_cache_yaml: false,
         compile_cache_json: false,
+        ignore_directories: nil,
+        readonly: false,
       )
 
       Bootsnap.default_setup
@@ -86,13 +94,36 @@ module Bootsnap
         cache_dir: @tmp_dir,
         development_mode: true,
         load_path_cache: true,
-        compile_cache_iseq: Bootsnap.iseq_cache_supported?,
+        compile_cache_iseq: true,
         compile_cache_yaml: true,
         compile_cache_json: true,
+        ignore_directories: nil,
+        readonly: false,
       )
       Bootsnap.expects(:logger=).with($stderr.method(:puts))
 
       Bootsnap.default_setup
     end
+
+    def test_default_setup_with_BOOTSNAP_IGNORE_DIRECTORIES
+      ENV["BOOTSNAP_IGNORE_DIRECTORIES"] = "foo,bar"
+
+      Bootsnap.expects(:setup).with(
+        cache_dir: @tmp_dir,
+        development_mode: true,
+        load_path_cache: true,
+        compile_cache_iseq: true,
+        compile_cache_yaml: true,
+        compile_cache_json: true,
+        ignore_directories: %w[foo bar],
+        readonly: false,
+      )
+
+      Bootsnap.default_setup
+    end
+
+    def test_unload_cache
+      Bootsnap.unload_cache!
+    end
   end
 end
